pub fn append<G, P>(g: &mut G, point: P)where
G: Append<P>,Expand description
Push point to the end of a Linestring or Ring.
Mirrors boost::geometry::append(g, point) from
boost/geometry/algorithms/append.hpp for the linear kinds.
pub fn append<G, P>(g: &mut G, point: P)where
G: Append<P>,Push point to the end of a Linestring or Ring.
Mirrors boost::geometry::append(g, point) from
boost/geometry/algorithms/append.hpp for the linear kinds.