convex_hull

Function convex_hull 

pub fn convex_hull<G, P>(g: &G) -> Ring<P, true, true>
where MonotoneChain: ConvexHullStrategy<G, Output = Ring<P, true, true>>, P: Point,
Compute the convex hull of g as a clockwise, closed Ring.

The output ring repeats its first vertex at the end (closed) and is wound clockwise, matching Boost’s default output ring from boost/geometry/algorithms/convex_hull.hpp.