for_each_point

Function for_each_point 

pub fn for_each_point<G, F>(g: &G, f: F)
where G: ForEachPoint, F: FnMut(&G::Point),
Apply f to every stored point of g, recursively.

Mirrors boost::geometry::for_each_point(g, f) from boost/geometry/algorithms/for_each.hpp. The closure is invoked once per stored point — a closed ring visits its closing vertex once (it appears once in storage).