Module linestring_segmentize

Module linestring_segmentize 

Split a linestring into equal-length pieces.

The default is Cartesian. The explicit-strategy entry also supports spherical Haversine measurement and great-circle interpolation.

Functions

linestring_segmentize
Split a linestring into equal Cartesian arc-length pieces.
linestring_segmentize_with
Split a linestring using an explicitly supplied measurement and interpolation strategy.