map_coords

Function map_coords 

pub fn map_coords<G, Q, F>(geometry: &G, map: F) -> G::Output
where G: MapCoords<Q>, Q: PointTrait, F: FnMut(&G::Point) -> Q,
Map every point in a stock geometry into a newly constructed geometry.

The point closure may change the scalar or coordinate-system type while the geometry’s topology and ring parameters are preserved.