Point at a bearing and distance from an angular-coordinate point.
The public entry wraps the direct geodesic formulas ported from Boost’s
formulas/*_direct.hpp and selects a default by coordinate-system family.
Functions
- destination
- Compute the destination using the point’s coordinate-system default.
- destination_
with - Compute the destination using an explicitly supplied direct strategy.