pub fn simplify_with<G, S>(g: &G, max_distance: f64, strategy: S) -> S::Outputwhere
S: SimplifyStrategy<G>,Expand description
Return a simplified copy of g using an explicit strategy.
Mirrors the strategy overload of boost::geometry::simplify from
boost/geometry/algorithms/simplify.hpp:993-1011. The strategy is the
final argument so calls read consistently with other _with entries in
this crate.